/* 
 Trivial corba footprint benchmark.
 Measures how many corba echo servers can run on same machine without 
 affecting performance.
 Copyright Dan Kegel & Dimi Shahbaz
 19 Feb 2002
 Licensed under the Gnu GPL v2 
 See http://www.kegel.com/dkcorbabench
*/

#include <errno.h>
#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/time.h>
#include <iostream.h>

static int die(int line)
{
	printf("Died at line %d, file %s!\n", line, __FILE__);
	kill(0, SIGKILL);
	exit(1);
}
#define DIE() die(__LINE__)

/* Display the system's memory statistics to stdout. */
static void	show_memory_usage(void)
{
	char buf[1024];
	int i;
	FILE *fp = fopen("/proc/meminfo", "r");
	if (!fp)
		return;
	
	for (i=0; i<2; i++) {
		if (!fgets(buf, sizeof(buf), fp))
			break;
		fputs(buf, stdout);
	}
	fclose(fp);
	fputs("\n", stdout);
}

/* Copy one line from fdin to fdout.  Line must have been written with a single write.*/
void copy_line(int fdin, int fdout)
{
	char buf[1024];

	int n = read(fdin, buf, 1024);

	if (n < 16)
		DIE();

	int nwritten = write(fdout, buf, n);

	if (n != nwritten)
		DIE();
}

/**
 Fork 1 to max_n pingees.  
 Measure time to ping all children.
 Abort if latency exeeds max_t milliseconds.
*/

int master_process(int max_n, int max_t, int argc, char **argv)
{
	int i;

	int pipe_to_pinger[2];
	int pipe_from_pinger[2];
	if (pipe(pipe_to_pinger))
		DIE();
	if (pipe(pipe_from_pinger))
		DIE();
	
	if (!fork()) {
		close(pipe_from_pinger[0]);
		close(pipe_to_pinger[1]);
		dup2(pipe_from_pinger[1], fileno(stdout));
		dup2(pipe_to_pinger[0], fileno(stdin));
		/* FIXME: pass entire list of arguments! */
		(void) argc;
		execl("./footprint1c", "./footprint1c", argv[1], NULL);
		DIE();
	}
	close(pipe_from_pinger[1]);
	close(pipe_to_pinger[0]);

	for (i=0; i<max_n; i++) {
		int pipe_from_child[2];
		if (pipe(pipe_from_child))
			DIE();
		if (!fork()) {
			/* child doesn't need the pinger fds at all */
			close(pipe_from_pinger[0]);
			close(pipe_to_pinger[1]);
			/* we're the child - start responding to pings */
			close(pipe_from_child[0]);
			/* Hook pipe to stdout */
			dup2(pipe_from_child[1], fileno(stdout));
			execl("./footprint1s", "./footprint1s", NULL);
			DIE();
		}
		close(pipe_from_child[1]);
		copy_line(pipe_from_child[0], pipe_to_pinger[1]);
		close(pipe_from_child[0]);

		//if ((i % 50) == 0) {
			int nwrite = write(pipe_to_pinger[1], "ping\n", 5);
			if (nwrite != 5) {
				std::cerr << "expected nwrite 5, got " << nwrite << endl;
				DIE();
			}
			char buf[9];
			int nread = read(pipe_from_pinger[0], buf, 9);
			if (nread != 9) {
				std::cerr << "expected nread 9, got " << nread << endl;
				DIE();
			}
			int latency = atoi(buf);
			printf("Latency to %d children is %d ms\n", i+1, latency);
			show_memory_usage();
			fflush(stdout);
			if (latency > max_t)
				break;
		//}
	}
	return i;
}

int main(int argc, char **argv)
{
	if (argc != 3) {
		std::cerr << "usage: footprint1 max_n max_t" << endl;
		exit(1);
	}
	int max_n = atoi(argv[1]);
	int max_t = atoi(argv[2]);
	int result;

	//close(0);
	//close(2);
	result = master_process(max_n, max_t, argc, argv);
	printf("Result: %d children supported at max_t of %d ms\n", result, max_t);
	// clean up all those children!
	// FIXME: should do this if user hits ^C, too
	kill(0, SIGKILL);

	return 0;
}
