/* 
 Subprogram run by footprint1.

 Measures latency to a bunch of echo servers.
 Accepts IOR's or 'ping' commands on stdin;
 responds to 'ping' with latency in milliseconds in ascii.

 Copyright Dan Kegel & Dimi Shahbaz
 19 Feb 2002
 Licensed under the Gnu GPL v2 
 See http://www.kegel.com/dkcorbabench
*/

#include <errno.h>
#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/time.h>
#include <iostream.h>

// FIXME
#ifdef RSSH_TAO
#include <tao/DynamicInterface/Request.h>
#endif

#include "footprint1_cln.hh"

static int die(int line)
{
	printf("Died at line %d, file %s!\n", line, __FILE__);
	kill(0, SIGKILL);
	exit(1);
}
#define DIE() die(__LINE__)

/**
 Ping n children, return how many milliseconds it takes.
*/
static int ping_n_servers(int n, Echo_var *servers)
{
	int i;
	struct timeval start_timeval;
	struct timeval end_timeval;
	gettimeofday(&start_timeval, NULL);

	CORBA::Request_var *req = new CORBA::Request_var[n];
	const char *arg = "Hello!";

	//std::cerr << "Send " << n << " pings..." << endl;

	/* Send all the pings */
	for (i=0; i<n; i++) {
	  req[i] = servers[i]->_request("echoString");
	  req[i]->add_in_arg() <<= CORBA::string_dup(arg);
	  req[i]->set_return_type(CORBA::_tc_string);

	  req[i]->send_deferred();

	}

	//std::cerr << "Wait for all the replies..." << endl;

	/* Wait for all replies */
	for (i=0; i<n; i++) {
		req[i]->get_response();
	  if( req[i]->env()->exception() ) {
		std::cerr << "echo_diiclt: An exception was thrown!" << endl;
		DIE();
	  }
	  const char* ret;
	  req[i]->return_value() >>= ret;

	  if (strcmp(ret, arg)) {
		  /* Return value does not match initial string. */
		  fprintf(stderr, "Returned value does not match.\n");
		  DIE();
	  }
	}

	//std::cerr << "Got all the replies." << endl;

	gettimeofday(&end_timeval, NULL);
	return (end_timeval.tv_sec-start_timeval.tv_sec) * 1000
	     + (end_timeval.tv_usec-start_timeval.tv_usec) / 1000;
}

int client_main(int argc, char **argv, int max_n)
{
	char buf[1024];
	Echo_var *servers;
	int n_servers = 0;
    CORBA::ORB_var orb = CORBA::ORB_init(argc, argv, "omniORB3");
	//std::cerr << "orb init!" << endl;

	servers = new Echo_var[max_n];

	while (gets(buf)) {
		//std::cerr << "Pinger: got " << buf << endl;
		if (strcmp(buf,"ping") == 0) {
			int elapsed = ping_n_servers(n_servers, servers);
			int nwritten;
			/* dkcorbabench requires that exactly 9 bytes are written. */
			char obuf[32];
			//std::cerr << "Writing result " << elapsed << endl << flush;
			sprintf(obuf, "%8d\n", elapsed);
			nwritten = write(fileno(stdout), obuf, 9);
			//std::cerr << "Wrote result; nwritten " << nwritten << endl << flush;
			if (nwritten != 9)
				DIE();
		} else {
			CORBA::Object_var obj = orb->string_to_object(buf);
			Echo_var echoref = Echo::_narrow(obj);
			if( CORBA::is_nil(echoref) ) {
				std::cerr << "Can't narrow reference to type Echo (or it was nil)." << endl;
				DIE();
			}
			servers[n_servers++] = echoref;
			// invoke an object method for the first time,
			// so tcp connection time not part of the measurement
			// (for fairness with footprint0)
			echoref->echoString("hello!");
		}
	}

	delete [] servers;
	return 0;
}

int main(int argc, char **argv)
{
	int max_n;
	if (argc != 2) {
		std::cerr << "usage: footprint1c max_n" << endl;
		exit(1);
	}
	max_n = atoi(argv[1]);
	client_main(argc, argv, max_n);
	return 0;
}

