/* 
 Subprogram run by footprint1.
 An echo server.
 Outputs its IOR to stdout.
 Nearly verbatim copy of omniorb's echo/eg2_impl.cc

 Changes copyright Dan Kegel & Dimi Shahbaz
 19 Feb 2002
 Licensed under the Gnu GPL v2 
 See http://www.kegel.com/dkcorbabench
*/

// eg2_impl.cc - This is the source code of example 2 used in Chapter 2
//               "The Basics" of the omniORB user guide.
//
//               This is the object implementation.
//
// Usage: eg2_impl
//
//        On startup, the object reference is printed to std::cerr as a
//        stringified IOR. This string should be used as the argument to 
//        eg2_clt.
//

#include <iostream.h>
#include <stdio.h>
#include <signal.h>
#include <stdlib.h>
#include <unistd.h>

#include "footprint1_srv.hh"

static int die(int line)
{
	std::cerr << "Died at line " << line << " file " << __FILE__ << endl;
	kill(0, SIGKILL);
	exit(1);
}
#define DIE() die(__LINE__)

class Echo_i : public POA_Echo,
	       public PortableServer::RefCountServantBase
{
public:
  inline Echo_i() {}
  virtual ~Echo_i() {}
#ifdef RSSH_TAO
  virtual char* echoString(const char* mesg, CORBA::Environment &env)
	ACE_THROW_SPEC ((CORBA::SystemException));
#else
  virtual char* echoString(const char* mesg);
#endif
};


#ifdef RSSH_TAO
char* Echo_i::echoString(const char* mesg, CORBA::Environment &env)
	ACE_THROW_SPEC ((CORBA::SystemException))
#else
char* Echo_i::echoString(const char* mesg)
#endif
{
  return CORBA::string_dup(mesg);
}

//////////////////////////////////////////////////////////////////////

int server_main(int argc, char** argv)
{
  try {
    CORBA::ORB_var orb = CORBA::ORB_init(argc, argv, "omniORB3");

    CORBA::Object_var obj = orb->resolve_initial_references("RootPOA");
    PortableServer::POA_var poa = PortableServer::POA::_narrow(obj);

    Echo_i* myecho = new Echo_i();

    PortableServer::ObjectId_var myechoid = poa->activate_object(myecho);

    // Obtain a reference to the object, and print it out as a
    // stringified IOR.
    obj = myecho->_this();
    CORBA::String_var sior(orb->object_to_string(obj));
    int len = strlen((char *) sior);
    char buf[1024];
    memcpy(buf, (char *)sior, len);
    buf[len++] = '\n';
    int nwrite = write(fileno(stdout), buf, len);
    if (len != nwrite)
	DIE();

    myecho->_remove_ref();

    PortableServer::POAManager_var pman = poa->the_POAManager();
    pman->activate();

    orb->run();
    orb->destroy();
  }
  catch(CORBA::SystemException&) {
    std::cerr << "Caught CORBA::SystemException." << endl;
  }
  catch(CORBA::Exception&) {
    std::cerr << "Caught CORBA::Exception." << endl;
  }
#ifdef OMNIORB
  catch(omniORB::fatalException& fe) {
    std::cerr << "Caught omniORB::fatalException:" << endl;
    std::cerr << "  file: " << fe.file() << endl;
    std::cerr << "  line: " << fe.line() << endl;
    std::cerr << "  mesg: " << fe.errmsg() << endl;
  }
#endif
  catch(...) {
    std::cerr << "Caught unknown exception." << endl;
  }

  return 0;
}

int main(int argc, char **argv)
{
	server_main(argc, argv);
	
	return 0;
}
